@@ -303,9 +303,9 @@ class DefaultEmitter(Emitter):
         for a in assets:
             self.__write_asset(a)
 
-    def reduce_entities(self, identities: typing.List[int]):
-        for k in identities:
-            entity = self.entity_map[k].reduce()
+    def reduce_entities(self):
+        for k, e in self.entity_map.items():
+            entity = e.reduce()
 
             f = self.__get_entities_fd(entity)
             p = entity.to_proto()
@@ -313,9 +313,9 @@ class DefaultEmitter(Emitter):
             f.write(_VarintBytes(p.ByteSize()))
             f.write(p.SerializeToString())
 
-    def reduce_relationships(self, identities: typing.List[int]):
-        for k in identities:
-            relationship = self.rel_map[k].reduce()
+    def reduce_relationships(self):
+        for k, r in self.rel_map.items():
+            relationship = r.reduce()
 
             f = self.__get_relationships_fd(relationship)
             p = relationship.to_proto()
@@ -323,71 +323,29 @@ class DefaultEmitter(Emitter):
             f.write(_VarintBytes(p.ByteSize()))
             f.write(p.SerializeToString())
 
-    def __reduce_entities(self, executor: concurrent.futures.ThreadPoolExecutor):
-        pending_identities = set(self.entity_map.keys())
-        tasks = []
-
-        for i in range(PARTITION_NUM):
-            tasks.append(
-                executor.submit(self.reduce_entities, [c for c in pending_identities if c % PARTITION_NUM == i]))
-
-        for rt in tasks:
-            _ = rt.result()
-
-        self.entity_map = None
-
-    def __reduce_relationships(self, executor: concurrent.futures.ThreadPoolExecutor):
-        pending_identities = set(self.rel_map.keys())
-        tasks = []
-
-        for i in range(PARTITION_NUM):
-            tasks.append(
-                executor.submit(self.reduce_relationships, [c for c in pending_identities if c % PARTITION_NUM == i]))
-
-        for rt in tasks:
-            _ = rt.result()
-
-        self.rel_map = None
-
     def close(self):
-        with concurrent.futures.ThreadPoolExecutor(max_workers=PARTITION_NUM) as executor:
-            self.__reduce_entities(executor)
-            self.__reduce_relationships(executor)
+        self.reduce_entities()
+        self.reduce_relationships()
 
-            tasks = []
+        for k, v in self.fd_map.items():
+            v.close()
 
-            for k, v in self.fd_map.items():
-                v.close()
+            if k.startswith("entities"):
+                self.entities_lz.upload(v.name, self.ctx.entities_output_location, ".proto.gz", prefix="entities")
 
-                if k.startswith("entities"):
-                    tasks.append(executor.submit(self.entities_lz.upload,
-                                                 v.name,
-                                                 self.ctx.entities_output_location,
-                                                 ".proto.gz",
-                                                 prefix="entities",
-                                                 ))
-                elif k.startswith("relationships"):
-                    tasks.append(executor.submit(self.relationships_lz.upload,
-                                                 v.name,
-                                                 self.ctx.relationships_output_location,
-                                                 ".proto.gz",
-                                                 prefix="relationships",
-                                                 ))
-                elif k == "errors":
-                    self.errors_lz.upload(
-                        v.name,
-                        self.ctx.errors_output_location,
-                        ".proto.gz",
-                        prefix="errors",
-                    )
-                else:
-                    asset_code = k
-                    if self.asset_num_sharding > 1:
-                        asset_code = asset_code.split('___')[0]
+            elif k.startswith("relationships"):
+                self.relationships_lz.upload(v.name, self.ctx.relationships_output_location, ".proto.gz",
+                                             prefix='relationships')
 
-                        tasks.append(executor.submit(self.assets_lz.upload,
-                                                     v.name,
-                                                     self.ctx.assets_output_location + asset_code + "/",
-                                                     ".csv.gz",
-                                                     ))
-                _ = [_.result() for _ in tasks]
+            elif k == "errors":
+                self.errors_lz.upload(
+                    v.name,
+                    self.ctx.errors_output_location,
+                    ".proto.gz",
+                    prefix="errors",
+                )
+            else:
+                asset_code = k
+                if self.asset_num_sharding > 1:
+                    asset_code = asset_code.split('___')[0]
+                    self.assets_lz.upload(v.name, self.ctx.assets_output_location + asset_code + "/", ".csv.gz")
